/**
 This code demonstrate the usage of OLED display (SSD1306 i2c ) with stm32f4xx mcu
 The utilitiezed mcu is stm32f407vetx and the code is ddeveloped using keil uvision software 
 The code use bare metal method ( direct register manipulation ) to drive the oled display 
 The setting for the mcu was as following
 core speed =100MHz
 i2c speed = 100KHz
 
 */



#include "oled.h"
#include "test.h"
#include "bitmap.h"
#include "horse_anim.h"
#include "stdio.h"



void SysClockConfig(void) //set the core frequency to 100MHz
{
#define PLL_M      4
#define PLL_N      200
#define PLL_P      4
#define PLL_Q      2
	
__IO uint32_t StartUpCounter = 0, HSEStatus = 0;
  

  RCC->CR |= ((uint32_t)RCC_CR_HSEON);
 

  do
  {
    HSEStatus = RCC->CR & RCC_CR_HSERDY;
    StartUpCounter++;
  } while((HSEStatus == 0) && (StartUpCounter != 3000));

  if ((RCC->CR & RCC_CR_HSERDY) != RESET)
  {
    HSEStatus = (uint32_t)0x01;
  }
  else
  {
    HSEStatus = (uint32_t)0x00;
  }

  if (HSEStatus == (uint32_t)0x01)
  {
 
    RCC->APB1ENR |= RCC_APB1ENR_PWREN;
    PWR->CR &= (uint32_t)~(PWR_CR_VOS);


    RCC->CFGR |= RCC_CFGR_HPRE_DIV1;
      

    RCC->CFGR |= RCC_CFGR_PPRE2_DIV1;
    

    RCC->CFGR |= RCC_CFGR_PPRE1_DIV2;


    RCC->PLLCFGR = PLL_M | (PLL_N << 6) | (((PLL_P >> 1) -1) << 16) |
                   (RCC_PLLCFGR_PLLSRC_HSE) | (PLL_Q << 24);


    RCC->CR |= RCC_CR_PLLON;

    
    while((RCC->CR & RCC_CR_PLLRDY) == 0)
    {
    }
   
    /* Configure Flash prefetch, Instruction cache, Data cache and wait state */
    FLASH->ACR = FLASH_ACR_ICEN |FLASH_ACR_DCEN |FLASH_ACR_LATENCY_3WS;

    /* Select the main PLL as system clock source */
    RCC->CFGR &= (uint32_t)((uint32_t)~(RCC_CFGR_SW));
    RCC->CFGR |= RCC_CFGR_SW_PLL;

    /* Wait till the main PLL is used as system clock source */
    while ((RCC->CFGR & (uint32_t)RCC_CFGR_SWS ) != RCC_CFGR_SWS_PLL)
    {;}
  }
  else
  { /* If HSE fails to start-up, the application will have wrong clock
         configuration. User can add here some code to deal with this error */
  }

}





char zz[10];
int main(void)
{
SysClockConfig();
SSD1306_Init();
SSD1306_GotoXY (0,0);
	
SSD1306_Puts ("Embedded", &Font_7x10, 1);
	
SSD1306_GotoXY (0, 10);
	
SSD1306_Puts ("Expret.io", &Font_7x10, 1);
	
SSD1306_GotoXY (0, 30);
	
SSD1306_Puts ("OLED Display", &Font_7x10, 1);
	
SSD1306_GotoXY (0, 50);
	
SSD1306_Puts ("Bare Metal Code", &Font_7x10, 1);
	
SSD1306_UpdateScreen(); //display
	
delay (2000);
	
SSD1306_ScrollRight(0,7);  // scroll entire screen

delay(2000);  // 2 sec

SSD1306_ScrollLeft(0,7);  // scroll entire screen
	
delay(2000);  // 2 sec

SSD1306_Stopscroll();
	
SSD1306_ScrollRight(0x00, 0x0f);    // scroll entire screen right

delay (2000);

SSD1306_ScrollLeft(0x00, 0x0f);  // scroll entire screen left

delay (2000);

SSD1306_Scrolldiagright(0x00, 0x0f);  // scroll entire screen diagonal right

delay (2000);

SSD1306_Scrolldiagleft(0x00, 0x0f);  // scroll entire screen diagonal left

delay (2000);

SSD1306_Stopscroll();   // stop scrolling. If not done, screen will keep on scrolling


SSD1306_InvertDisplay(1);   // invert the display

delay(2000);

SSD1306_InvertDisplay(0);  // normalize the display


delay(2000);
SSD1306_Clear();
SSD1306_GotoXY (0,0);
SSD1306_Puts ("variable", &Font_7x10, 1);
SSD1306_UpdateScreen();

for (int i=0; i<100;i++)
{
sprintf(zz,"%i",i);
SSD1306_GotoXY (10, 30);	
SSD1306_Puts (zz, &Font_7x10, 1);
SSD1306_UpdateScreen();
delay(100);

}


while(1)
{
SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse1,128,64,1);
SSD1306_UpdateScreen();

SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse2,128,64,1);
SSD1306_UpdateScreen();

SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse3,128,64,1);
SSD1306_UpdateScreen();

SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse4,128,64,1);
SSD1306_UpdateScreen();

SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse5,128,64,1);
SSD1306_UpdateScreen();

SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse6,128,64,1);
SSD1306_UpdateScreen();


SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse7,128,64,1);
SSD1306_UpdateScreen();

SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse8,128,64,1);
SSD1306_UpdateScreen();


SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse9,128,64,1);
SSD1306_UpdateScreen();


SSD1306_Clear();
SSD1306_DrawBitmap(0,0,horse10,128,64,1);
SSD1306_UpdateScreen();	
	
}


}